Sorted = {}

local locales = {
    [1] = "enUS",
    [2] = "enGB",
    [3] = "frFR",
    [4] = "deDE",
    [5] = "itIT",
    [6] = "koKR",
    [7] = "zhCN",
    [8] = "zhTW",
    [9] = "ruRU",
    [10] = "esES",
    [11] = "esMX",
    [12] = "ptBR",
}
local localizations = {}
for _, locale in pairs(locales) do
    localizations[locale] = {}
end

local function ParseTSV()
-- Tab Separated Values spreadsheet imported directly from https://docs.google.com/spreadsheets/d/17eIDO0UU86-DUYjvu_ZyJ_9b8kMA9kTbAMDiQ0elXQA/edit?usp=sharing
local tsv = 
[[TITLE	Sorted.	Sorted.										
CATEGORY_WEAPONS	Weapons	Weapons	Armes	Waffen	Armi	무기	武器	武器	Оружие	Armas	Armas	Armas
CATEGORY_ARMOR	Armor	Armour	Armure	Rüstung	Armature	방어구	护甲	護甲	Доспехи	Armadura	Armadura	Armadura
CATEGORY_ACCESSORIES	Accessories	Accessories	Accessoires	Accessoires								
CATEGORY_CONTAINERS	Containers	Containers	Conteneurs	Behälter	Borse	가방류	容器	容器	Сумки	Recipientes	Contenedores	Recipientes
CATEGORY_GEMS	Gems	Gems	Gemmes	Edelsteine	Gemme	보석	宝石	寶石	Камни	Gemas	Gemas	Gemas
CATEGORY_ITEM_ENHANCEMENTS	Item Enhancements	Item Enhancements	Améliorations d’objet	Gegenstandsverbesserungen	Potenziamenti oggetto	아이템 강화	物品附魔	物品附魔	Улучшения предметов	Mejoras de objetos	Mejoras de objetos	Aperfeiçoamentos de Itens
CATEGORY_CONSUMABLES	Consumables	Consumables	Consommables	Verbrauchbare Gegenstände	Consumabili	소비용품	消耗品	消耗品	Расход. предметы	Consumibles	Consumibles	Consumíveis
CATEGORY_GLYPHS	Glyphs	Glyphs	Glyphes	Glyphen	Glifi	문양	雕文	雕紋	Символы	Glifos	Glifos	Glifos
CATEGORY_TRADE_GOODS	Trade Goods	Trade Goods	Fournitures d’artisanat	Handwerkswaren	Beni commerciali	직업용품	杂货	商品	Хозяйственные товары	Objetos comerciales	Objetos comerciables	Mercadorias
CATEGORY_RECIPES	Recipes	Recipes	Recettes	Rezepte	Ricette	제조법	配方	配方	Рецепты	Recetas	Recetas	Receitas
CATEGORY_BATTLE_PETS	Battle Pets	Battle Pets	Mascottes de combat	Kampfhaustiere	Mascotte da combattimento	전투 애완동물	战斗宠物	戰寵	Боевые питомцы	Mascotas de duelo	Mascotas de duelo	Mascotes de Batalha
CATEGORY_QUEST_ITEMS	Quest Items	Quest Items	Objets de quête	Questgegenstände	Oggetti di missione	퀘스트 아이템	任务物品	任務物品	Предметы	Objetos de misión	Objetos con misión	Itens de missão
CATEGORY_MISCELLANEOUS	Miscellaneous	Miscellaneous	Divers	Verschiedenes	Varie	기타	杂项	雜項	Разное	Miscelánea	Miscelánea	Diversos
ITEM_UNKNOWN_KEYSTONE	Mythic Keystone	Mythic Keystone										
ITEM_MYTHIC_KEYSTONE	Keystone: %s	Keystone: %s										
ITEM_PET_CAGED	Pet Cage: %s	Pet Cage: %s										
COLUMN_FAVORITES	Favorites	Favourites										
COLUMN_QUANTITY	Quantity	Quantity										
COLUMN_NAME	Name	Name										
COLUMN_NAME_SHORT	Name	Name										
COLUMN_REQUIRED_LEVEL	Required Level	Required Level										
COLUMN_REQUIRED_LEVEL_SHORT	Req	Req										
COLUMN_ITEM_LEVEL	Item Level	Item Level										
COLUMN_ITEM_LEVEL_SHORT	Lvl	Lvl										
COLUMN_TYPE	Type	Type										
COLUMN_TYPE_SHORT	Type	Type										
COLUMN_BINDING	Binding	Binding										
COLUMN_BINDING_SHORT	Bind	Bind										
COLUMN_EXPANSION	Expansion	Expansion										
COLUMN_EXPANSION_SHORT	Expac	Expac										
COLUMN_SELL_PRICE	Sell Price	Sell Price										
COLUMN_SELL_PRICE_SHORT	Value	Value										
TAB_BANK	Bank	Bank										
TAB_REAGENTS	Reagents	Reagents										
BUTTON_DEPOSIT_REAGENTS	Deposit Reagents	Deposit Reagents										
BUTTON_BUY_BANK_SLOT	Purchase Bag Slot	Purchase Bag Slot										
BUTTON_BUY_REAGENTS	Purchase	Purchase										
WARNING_BUY_REAGENTS	This tab gives you additional storage for raw profession materials.\nDo you wish to purchase this tab?	This tab gives you additional storage for raw profession materials.\nDo you wish to purchase this tab?										
WARNING_NO_ITEMS_FOUND	No items found	No items found										
WARNING_BANK_NOT_CACHED	Visit a banker once on %s\n to see their bank contents here	Visit a banker once on %s\n to see their bank contents here										
WARNING_REAGENTS_NOT_CACHED	Visit a banker once on %s\n to see the contents of their reagent bank here	Visit a banker once on %s\n to see the contents of their reagent bank here										
WARNING_REAGENTS_NOT_PURCHASED	Visit a banker on %s\n to purchase their reagent bank	Visit a banker on %s\n to purchase their reagent bank										
EQUIPMENT_SETS	Equipment Sets	Equipment Sets										
DROPDOWN_MENU_CLEAR	Clear	Clear										
FILTER_TYPE	Type	Type										
FILTER_EQUIP_LOCATION	Equip Location	Equip Location										
FILTER_SUBTYPE	Subtype	Subtype										
FILTER_STATS	Stats	Stats										
FILTER_QUALITY	Quality	Quality										
FILTER_TIME_ADDED	Time Added	Time Added										
FILTER_BINDING	Binding	Binding										
FILTER_EXPANSION	Expansion	Expansion										
FILTER_LEVEL	Level	Level										
FILTER_MARKER_ICON	Marker Icon	Marker Icon										
FILTER_NAME_SEARCH	Name Search	Name Search										
FILTER_SPECIFIC_ITEMS	Specific Items	Specific Items										
SUBFILTER_TYPE_ARMOR	Armor	Armour										
SUBFILTER_TYPE_BATTLE_PET	Battle Pet	Battle Pet										
SUBFILTER_TYPE_CONSUMABLE	Consumable	Consumable										
SUBFILTER_TYPE_CONTAINER	Container	Container										
SUBFILTER_TYPE_GEM	Gem	Gem										
SUBFILTER_TYPE_GLYPH	Glyph	Glyph										
SUBFILTER_TYPE_ITEM_ENHANCEMENT	Item Enhancement	Item Enhancement										
SUBFILTER_TYPE_KEY	Key	Key										
SUBFILTER_TYPE_MISCELLANEOUS	Miscellaneous	Miscellaneous										
SUBFILTER_TYPE_REAGENT	Reagent	Reagent										
SUBFILTER_TYPE_RECIPE	Recipe	Recipe										
SUBFILTER_TYPE_PROJECTILE	Projectile	Projectile										
SUBFILTER_TYPE_QUEST	Quest	Quest										
SUBFILTER_TYPE_QUIVER	Quiver	Quiver										
SUBFILTER_TYPE_TRADE_GOODS	Trade Good	Trade Good										
SUBFILTER_TYPE_WEAPON	Weapon	Weapon										
SUBFILTER_EQUIP_LOCATION_HEAD	Head	Head										
SUBFILTER_EQUIP_LOCATION_NECK	Neck	Neck										
SUBFILTER_EQUIP_LOCATION_SHOULDER	Shoulder	Shoulder										
SUBFILTER_EQUIP_LOCATION_BACK	Back	Back										
SUBFILTER_EQUIP_LOCATION_CHEST	Chest	Chest										
SUBFILTER_EQUIP_LOCATION_SHIRT	Shirt	Shirt										
SUBFILTER_EQUIP_LOCATION_TABARD	Tabard	Tabard										
SUBFILTER_EQUIP_LOCATION_WRIST	Wrist	Wrist										
SUBFILTER_EQUIP_LOCATION_HANDS	Hands	Hands										
SUBFILTER_EQUIP_LOCATION_WAIST	Waist	Waist										
SUBFILTER_EQUIP_LOCATION_LEGS	Legs	Legs										
SUBFILTER_EQUIP_LOCATION_FEET	Feet	Feet										
SUBFILTER_EQUIP_LOCATION_FINGER	Finger	Finger										
SUBFILTER_EQUIP_LOCATION_TRINKET	Trinket	Trinket										
SUBFILTER_EQUIP_LOCATION_OFF_HAND	Off-Hand	Off-Hand										
SUBFILTER_EQUIP_LOCATION_RELIC	Relic	Relic										
SUBFILTER_EQUIP_LOCATION_ONE_HAND	One-Handed	One-Handed										
SUBFILTER_EQUIP_LOCATION_TWO_HAND	Two-Handed	Two-Handed										
SUBFILTER_EQUIP_LOCATION_RANGED	Ranged	Ranged										
SUBFILTER_SUBTYPE_ARMOR_PLATE	Plate	Plate										
SUBFILTER_SUBTYPE_ARMOR_MAIL	Mail	Mail										
SUBFILTER_SUBTYPE_ARMOR_LEATHER	Leather	Leather										
SUBFILTER_SUBTYPE_ARMOR_CLOTH	Cloth	Cloth										
SUBFILTER_SUBTYPE_ARMOR_COSMETIC	Cosmetic	Cosmetic										
SUBFILTER_SUBTYPE_ARMOR_GENERIC	Generic	Generic										
SUBFILTER_SUBTYPE_ARMOR_SHIELDS	Shields	Shields										
SUBFILTER_SUBTYPE_ARMOR_LIBRAMS	Librams	Librams										
SUBFILTER_SUBTYPE_ARMOR_IDOLS	Idols	Idols										
SUBFILTER_SUBTYPE_ARMOR_TOTEMS	Totems	Totems										
SUBFILTER_SUBTYPE_ARMOR_SIGILS	Sigils	Sigils										
SUBFILTER_SUBTYPE_BATTLE_PET_HUMANOID	Humanoid	Humanoid										
SUBFILTER_SUBTYPE_BATTLE_PET_DRAGON	Dragon	Dragon										
SUBFILTER_SUBTYPE_BATTLE_PET_FLYING	Flying	Flying										
SUBFILTER_SUBTYPE_BATTLE_PET_UNDEAD	Undead	Undead										
SUBFILTER_SUBTYPE_BATTLE_PET_CRITTER	Critter	Critter										
SUBFILTER_SUBTYPE_BATTLE_PET_MAGICAL	Magical	Magical										
SUBFILTER_SUBTYPE_BATTLE_PET_ELEMENTAL	Elemental	Elemental										
SUBFILTER_SUBTYPE_BATTLE_PET_BEAST	Beast	Beast										
SUBFILTER_SUBTYPE_BATTLE_PET_WATER	Water	Water										
SUBFILTER_SUBTYPE_BATTLE_PET_MECHANICAL	Mechanical	Mechanical										
SUBFILTER_SUBTYPE_CONSUMABLE_BOMBS_AND_DEVICES	Bombs and Devices	Bombs and Devices										
SUBFILTER_SUBTYPE_CONSUMABLE_POTIONS	Potions	Potions										
SUBFILTER_SUBTYPE_CONSUMABLE_ELIXIRS	Elixirs	Elixirs										
SUBFILTER_SUBTYPE_CONSUMABLE_FLASKS	Flasks	Flasks										
SUBFILTER_SUBTYPE_CONSUMABLE_FOOD_AND_DRINK	Food & Drink	Food & Drink										
SUBFILTER_SUBTYPE_CONSUMABLE_BANDAGES	Bandages	Bandages										
SUBFILTER_SUBTYPE_CONSUMABLE_VANTUS_RUNES	Vantus Runes	Vantus Runes										
SUBFILTER_SUBTYPE_CONSUMABLE_OTHER	Other	Other										
SUBFILTER_SUBTYPE_CONTAINER_BAG	Bag	Bag										
SUBFILTER_SUBTYPE_CONTAINER_SOUL	Soul Bag	Soul Bag										
SUBFILTER_SUBTYPE_CONTAINER_HERB	Herb Bag	Herb Bag										
SUBFILTER_SUBTYPE_CONTAINER_ENCHANTING	Enchanting Bag	Enchanting Bag										
SUBFILTER_SUBTYPE_CONTAINER_ENGINEERING	Engineering Bag	Engineering Bag										
SUBFILTER_SUBTYPE_CONTAINER_GEM	Gem Bag	Gem Bag										
SUBFILTER_SUBTYPE_CONTAINER_MINING	Mining Bag	Mining Bag										
SUBFILTER_SUBTYPE_CONTAINER_LEATHERWORKING	Leatherworking Bag	Leatherworking Bag										
SUBFILTER_SUBTYPE_CONTAINER_INSCRIPTION	Inscription Bag	Inscription Bag										
SUBFILTER_SUBTYPE_CONTAINER_TACKLE	Tackle Box	Tackle Box										
SUBFILTER_SUBTYPE_CONTAINER_COOKING	Cooking Bag	Cooking Bag										
SUBFILTER_SUBTYPE_GEM_INTELLECT	Intellect	Intellect										
SUBFILTER_SUBTYPE_GEM_AGILITY	Agility	Agility										
SUBFILTER_SUBTYPE_GEM_STRENGTH	Strength	Strength										
SUBFILTER_SUBTYPE_GEM_STAMINA	Stamina	Stamina										
SUBFILTER_SUBTYPE_GEM_SPIRIT	Spirit	Spirit										
SUBFILTER_SUBTYPE_GEM_CRITICAL_STRIKE	Critical Strike	Critical Strike										
SUBFILTER_SUBTYPE_GEM_MASTERY	Mastery	Mastery										
SUBFILTER_SUBTYPE_GEM_HASTE	Haste	Haste										
SUBFILTER_SUBTYPE_GEM_VERSATILITY	Versatility	Versatility										
SUBFILTER_SUBTYPE_GEM_OTHER	Other	Other										
SUBFILTER_SUBTYPE_GEM_MULTIPLE_STATS	Multiple Stats	Multiple Stats										
SUBFILTER_SUBTYPE_GEM_ARTIFACT_RELIC	Artifact Relic	Artefact Relic										
SUBFILTER_SUBTYPE_GLYPH_WARRIOR	Warrior	Warrior										
SUBFILTER_SUBTYPE_GLYPH_PALADIN	Paladin	Paladin										
SUBFILTER_SUBTYPE_GLYPH_HUNTER	Hunter	Hunter										
SUBFILTER_SUBTYPE_GLYPH_ROGUE	Rogue	Rogue										
SUBFILTER_SUBTYPE_GLYPH_PRIEST	Priest	Priest										
SUBFILTER_SUBTYPE_GLYPH_DEATH_KNIGHT	Death Knight	Death Knight										
SUBFILTER_SUBTYPE_GLYPH_SHAMAN	Shaman	Shaman										
SUBFILTER_SUBTYPE_GLYPH_MAGE	Mage	Mage										
SUBFILTER_SUBTYPE_GLYPH_WARLOCK	Warlock	Warlock										
SUBFILTER_SUBTYPE_GLYPH_MONK	Monk	Monk										
SUBFILTER_SUBTYPE_GLYPH_DRUID	Druid	Druid										
SUBFILTER_SUBTYPE_GLYPH_DEMON_HUNTER	Demon Hunter	Demon Hunter										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_HEAD	Head	Head										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_NECK	Neck	Neck										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_SHOULDER	Shoulder	Shoulder										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_CLOAK	Cloak	Cloak										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_CHEST	Chest	Chest										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_WRIST	Wrist	Wrist										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_HANDS	Hands	Hands										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_WAIST	Waist	Waist										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_LEGS	Legs	Legs										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_FEET	Feet	Feet										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_FINGER	Finger	Finger										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_ONE_HAND	One-Handed Weapons	One-Handed Weapons										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_TWO_HAND	Two-Handed Weapons	Two-Handed Weapons										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_SHIELD_OFF_HAND	Shield/Offhand	Shield/Offhand										
SUBFILTER_SUBTYPE_ITEM_ENHANCEMENT_MISCELLANEOUS	Misc	Misc										
SUBFILTER_SUBTYPE_KEY_KEY	Key	Key										
SUBFILTER_SUBTYPE_KEY_LOCKPICK	Lockpick	Lockpick										
SUBFILTER_SUBTYPE_MISCELLANEOUS_JUNK	Junk	Junk										
SUBFILTER_SUBTYPE_MISCELLANEOUS_REAGENTS	Spell Reagents	Spell Reagents										
SUBFILTER_SUBTYPE_MISCELLANEOUS_COMPANION_PETS	Companion Pets	Companion Pets										
SUBFILTER_SUBTYPE_MISCELLANEOUS_HOLIDAY	Holiday	Holiday										
SUBFILTER_SUBTYPE_MISCELLANEOUS_OTHER	Other	Other										
SUBFILTER_SUBTYPE_MISCELLANEOUS_MOUNT	Mount	Mount										
SUBFILTER_SUBTYPE_MISCELLANEOUS_MOUNT_EQUIPMENT	Mount Equipment	Mount Equipment										
SUBFILTER_SUBTYPE_RECIPE_BOOK	Book	Book										
SUBFILTER_SUBTYPE_RECIPE_LEATHERWORKING	Leatherworking	Leatherworking										
SUBFILTER_SUBTYPE_RECIPE_TAILORING	Tailoring	Tailoring										
SUBFILTER_SUBTYPE_RECIPE_ENGINEERING	Engineering	Engineering										
SUBFILTER_SUBTYPE_RECIPE_BLACKSMITHING	Blacksmithing	Blacksmithing										
SUBFILTER_SUBTYPE_RECIPE_COOKING	Cooking	Cooking										
SUBFILTER_SUBTYPE_RECIPE_ALCHEMY	Alchemy	Alchemy										
SUBFILTER_SUBTYPE_RECIPE_FIRST_AID	First Aid	First Aid										
SUBFILTER_SUBTYPE_RECIPE_ENCHANTING	Enchanting	Enchanting										
SUBFILTER_SUBTYPE_RECIPE_FISHING	Fishing	Fishing										
SUBFILTER_SUBTYPE_RECIPE_JEWELCRAFTING	Jewelcrafting	Jewelcrafting										
SUBFILTER_SUBTYPE_RECIPE_INSCRIPTION	Inscription	Inscription										
SUBFILTER_SUBTYPE_PROJECTILE_ARROW	Arrow	Arrow										
SUBFILTER_SUBTYPE_PROJECTILE_BULLET	Bullet	Bullet										
SUBFILTER_SUBTYPE_QUIVER_QUIVER	Quiver	Quiver										
SUBFILTER_SUBTYPE_QUIVER_AMMO_POUCH	Ammo Pouch	Ammo Pouch										
SUBFILTER_SUBTYPE_TRADE_GOODS_PARTS	Parts	Parts										
SUBFILTER_SUBTYPE_TRADE_GOODS_JEWELCRAFTING	Jewelcrafting	Jewelcrafting										
SUBFILTER_SUBTYPE_TRADE_GOODS_CLOTH	Cloth	Cloth										
SUBFILTER_SUBTYPE_TRADE_GOODS_LEATHER	Leather	Leather										
SUBFILTER_SUBTYPE_TRADE_GOODS_METAL_AND_STONE	Metal & Stone	Metal & Stone										
SUBFILTER_SUBTYPE_TRADE_GOODS_COOKING	Cooking	Cooking										
SUBFILTER_SUBTYPE_TRADE_GOODS_HERB	Herb	Herb										
SUBFILTER_SUBTYPE_TRADE_GOODS_ELEMENTAL	Elemental	Elemental										
SUBFILTER_SUBTYPE_TRADE_GOODS_ENCHANTING	Enchanting	Enchanting										
SUBFILTER_SUBTYPE_TRADE_GOODS_INSCRIPTION	Inscription	Inscription										
SUBFILTER_SUBTYPE_TRADE_GOODS_OTHER	Other	Other										
SUBFILTER_SUBTYPE_WEAPON_AXES	Axes	Axes										
SUBFILTER_SUBTYPE_WEAPON_MACES	Maces	Maces										
SUBFILTER_SUBTYPE_WEAPON_SWORDS	Swords	Swords										
SUBFILTER_SUBTYPE_WEAPON_DAGGERS	Daggers	Daggers										
SUBFILTER_SUBTYPE_WEAPON_POLEARMS	Polearms	Polearms										
SUBFILTER_SUBTYPE_WEAPON_FIST	Fist Weapons	Fist Weapons										
SUBFILTER_SUBTYPE_WEAPON_GLAIVES	Warglaives	Warglaives										
SUBFILTER_SUBTYPE_WEAPON_WANDS	Wands	Wands										
SUBFILTER_SUBTYPE_WEAPON_STAVES	Staves	Staves										
SUBFILTER_SUBTYPE_WEAPON_BOWS	Bows	Bows										
SUBFILTER_SUBTYPE_WEAPON_CROSSBOWS	Crossbows	Crossbows										
SUBFILTER_SUBTYPE_WEAPON_GUNS	Guns	Guns										
SUBFILTER_SUBTYPE_WEAPON_THROWN	Thrown	Thrown										
SUBFILTER_SUBTYPE_WEAPON_FISHING_POLES	Fishing Poles	Fishing Poles										
SUBFILTER_SUBTYPE_WEAPON_MISCELLANEOUS	Miscellaneous	Miscellaneous										
SUBFILTER_STATS_STAMINA	Stamina	Stamina										
SUBFILTER_STATS_STRENGTH	Strength	Strength										
SUBFILTER_STATS_AGILITY	Agility	Agility										
SUBFILTER_STATS_INTELLECT	Intellect	Intellect										
SUBFILTER_STATS_CRITICAL_STRIKE	Critical Strike	Critical Strike										
SUBFILTER_STATS_HASTE	Haste	Haste										
SUBFILTER_STATS_MASTERY	Mastery	Mastery										
SUBFILTER_STATS_VERSATILITY	Versatility	Versatility										
SUBFILTER_STATS_SPEED	Speed	Speed										
SUBFILTER_STATS_INDESTRUCTIBLE	Indestructible	Indestructible										
SUBFILTER_STATS_LEECH	Leech	Leech										
SUBFILTER_STATS_AVOIDANCE	Avoidance	Avoidance										
SUBFILTER_QUALITY_HEIRLOOM	Heirloom	Heirloom										
SUBFILTER_QUALITY_ARTIFACT	Artifact	Artefact										
SUBFILTER_QUALITY_LEGENDARY	Legendary	Legendary										
SUBFILTER_QUALITY_EPIC	Epic	Epic										
SUBFILTER_QUALITY_RARE	Rare	Rare										
SUBFILTER_QUALITY_UNCOMMON	Uncommon	Uncommon										
SUBFILTER_QUALITY_COMMON	Common	Common										
SUBFILTER_QUALITY_POOR	Poor	Poor										
SUBFILTER_TIME_SECONDS	Seconds	Seconds										
SUBFILTER_TIME_SECONDS_SHORT	Secs	Secs										
SUBFILTER_TIME_MINUTES	Minutes	Minutes										
SUBFILTER_TIME_MINUTES_SHORT	Mins	Mins										
SUBFILTER_TIME_HOURS	Hours	Hours										
SUBFILTER_TIME_HOURS_SHORT	Hrs	Hrs										
SUBFILTER_TIME_DAYS	Days	Days										
SUBFILTER_TIME_DAYS_SHORT	Days	Days										
SUBFILTER_TIME_WEEKS	Weeks	Weeks										
SUBFILTER_TIME_WEEKS_SHORT	Wks	Wks										
SUBFILTER_TIME_MONTHS	Months	Months										
SUBFILTER_TIME_MONTHS_SHORT	Mths	Mths										
SUBFILTER_TIME_SECOND_SHORT	Sec	Sec										
SUBFILTER_TIME_MINUTE_SHORT	Min	Min										
SUBFILTER_TIME_HOUR_SHORT	Hour	Hour										
SUBFILTER_TIME_DAY_SHORT	Day	Day										
SUBFILTER_TIME_WEEK_SHORT	Week	Week										
SUBFILTER_TIME_MONTH_SHORT	Mnth	Mnth										
SUBFILTER_BINDING_NONE	None	None										
SUBFILTER_BINDING_ON_EQUIP	Bind on Equip	Bind on Equip										
SUBFILTER_BINDING_ON_EQUIP_SHORT	Equip	Equip										
SUBFILTER_BINDING_ON_PICKUP	Bind on Pickup	Bind on Pickup										
SUBFILTER_BINDING_ON_PICKUP_SHORT	Pickup	Pickup										
SUBFILTER_BINDING_ON_USE	Bind on Use	Bind on Use										
SUBFILTER_BINDING_ON_USE_SHORT	Use	Use										
SUBFILTER_BINDING_SOULBOUND	Soulbound	Soulbound										
SUBFILTER_BINDING_SOULBOUND_SHORT	Bound	Bound										
SUBFILTER_EXPANSION_TBC	The Burning Crusade	The Burning Crusade										
SUBFILTER_EXPANSION_TBC_SHORT	TBC	TBC										
SUBFILTER_EXPANSION_WOTLK	Wrath of the Lich King	Wrath of the Lich King										
SUBFILTER_EXPANSION_WOTLK_SHORT	Wrath	Wrath										
SUBFILTER_EXPANSION_CATA	Cataclysm	Cataclysm										
SUBFILTER_EXPANSION_CATA_SHORT	Cata	Cata										
SUBFILTER_EXPANSION_MOP	Mists of Pandaria	Mists of Pandaria										
SUBFILTER_EXPANSION_MOP_SHORT	MoP	MoP										
SUBFILTER_EXPANSION_WOD	Warlords of Draenor	Warlords of Draenor										
SUBFILTER_EXPANSION_WOD_SHORT	WoD	WoD										
SUBFILTER_EXPANSION_LEGION	Legion	Legion										
SUBFILTER_EXPANSION_LEGION_SHORT	Legion	Legion										
SUBFILTER_EXPANSION_BFA	Battle for Azeroth	Battle for Azeroth										
SUBFILTER_EXPANSION_BFA_SHORT	BfA	BfA										
SUBFILTER_EXPANSION_SHADOW	Shadowlands	Shadowlands										
SUBFILTER_EXPANSION_SHADOW_SHORT	Shadow	Shadow										
SUBFILTER_LEVEL_ITEM_LEVEL	Item Level	Item Level										
SUBFILTER_LEVEL_REQUIRED_LEVEL	Required Level	Required Level										
SUBFILTER_MARKER_ICON_NONE	None	None										
SUBFILTER_SPECIFIC_ITEMS_ID	ID	ID										
SUBFILTER_SPECIFIC_ITEMS_NAME	Name	Name										
CONFIG_APPEARANCE	Appearance	Appearance										
CONFIG_BEHAVIOR	Behavior	Behavior										
CONFIG_CATEGORIES	Categories	Categories										
CONFIG_COLUMNS	Columns	Columns										
CONFIG_PROFILES	Profiles	Profiles										
CONFIG_APPEARANCE_SCALE	Scale	Scale										
CONFIG_APPEARANCE_ICON_SIZE	Icon Size	Icon Size										
CONFIG_APPEARANCE_ICON_BORDERS	Icon Borders	Icon Borders										
CONFIG_APPEARANCE_SPACING	Spacing	Spacing										
CONFIG_APPEARANCE_BACKDROP_OPACITY	Backdrop Opacity	Backdrop Opacity										
CONFIG_APPEARANCE_FONT	Font	Font										
CONFIG_APPEARANCE_FONT_SIZE	Size	Size										
CONFIG_APPEARANCE_FONT_OUTLINE	Outline	Outline										
CONFIG_APPEARANCE_SIDE_PANE_WIDTH	Side Pane Width	Side Pane Width										
CONFIG_APPEARANCE_ALWAYS_USE_ICONS	Always Use Icons	Always Use Icons										
CONFIG_BEHAVIOR_SCROLL_WHEEL_SPEED	Wheel Scroll Speed	Wheel Scroll Speed										
CONFIG_BEHAVIOR_SMOOTH_SCROLLING	Smooth Scrolling	Smooth Scrolling										
CONFIG_BEHAVIOR_ANIMATIONS	Animations	Animations										
CONFIG_BEHAVIOR_RESET_WINDOW	Reset Window on Close	Reset Window on Close										
CONFIG_BEHAVIOR_COMBINE_STACKS	Combine Stacks	Combine Stacks										
CONFIG_BEHAVIOR_TOOLTIP_DELAY	Tooltip Delay	Tooltip Delay										
CONFIG_BEHAVIOR_TOOLTIP_DELAY_SECOND	Second	Second										
CONFIG_BEHAVIOR_TOOLTIP_DELAY_SECONDS	Seconds	Seconds										
CONFIG_CATEGORIES_NAME	Name	Name										
CONFIG_CATEGORIES_ICON	Icon	Icon										
CONFIG_CATEGORIES_FILTERS	Filters	Filters										
CONFIG_CATEGORIES_ADD	Add Category	Add Category										
CONFIG_COLUMNS_COLUMN	Column	Column										
CONFIG_COLUMNS_WIDTH	Width	Width										
CONFIG_COLUMNS_ENABLED	Enabled	Enabled										
CONFIG_PROFILES_PROFILE	Settings Profile	Settings Profile										
CONFIG_PROFILES_NAME	Name	Name										
CONFIG_PROFILES_NEW	New	New										
CONFIG_PROFILES_COPY	Copy	Copy										
CONFIG_PROFILES_DELETE	Delete	Delete										
CONFIG_PROFILES_DEFAULT_NAME	New Profile	New Profile										
TOOLTIP_TITLE_ACCOUNT_GOLD	Account Gold	Account Gold										
TOOLTIP_TITLE_BAGS	Bags	Bags										
TOOLTIP_TITLE_BANK	Bank Bags	Bank Bags										
TOOLTIP_TITLE_REAGENTS	Reagent Bank	Reagent Bank										
TOOLTIP_CONFIG	Configure Sorted.	Configure Sorted.										
TOOLTIP_MINIMISE	Hide Side Panel	Hide Side Panel										
TOOLTIP_MAXIMISE	Show Side Panel	Show Side Panel										
TOOLTIP_KEYRING	Keyring	Keyring										
TOOLTIP_CLEANUP_BAGS	< Click to Clean Up Bags >	< Click to Clean Up Bags >										
TOOLTIP_CLEANUP_BANK	< Click to Clean Up Bank >	< Click to Clean Up Bank >										
TOOLTIP_CLEANUP_REAGENTS	< Click to Clean Up Reagents >	< Click to Clean Up Reagents >										
TOOLTIP_FORGET_CHARACTER	Forget %s\nFree up memory by clearing the data that Sorted has kept on this characters.\n|cffff000000You will no longer be able to preview their items!	Forget %s\nFree up memory by clearing the data that Sorted has kept on this characters.\n|cffff000000You will no longer be able to preview their items!										
TOOLTIP_CONFIG_ALWAYS_USE_ICONS	Always Use Icons:\n|cffffffffHides the default category buttons and forces Sorted \nto use the icons instead, which usually only show when \nthe side pane is minimised.\n\n|cffffee00With this checked, and the side pane maximised, the entire height\nof the window will be used for the category's checkbuttons.\nIn this case, the side pane hides automatically.	Always Use Icons:\n|cffffffffHides the default category buttons and forces Sorted \nto use the icons instead, which usually only show when \nthe side pane is minimised.\n\n|cffffee00With this checked, and the side pane maximised, the entire height\nof the window will be used for the category's checkbuttons.\nIn this case, the side pane hides automatically.										
TOOLTIP_CONFIG_SCROLL_WHEEL_SPEED	Wheel Scroll Speed:\n|cffffffffAdjust how far Sorted should scroll\nper each step of the scroll wheel.\n\n|cffffee00(You can hold ALT at any time to scroll quickly)	Wheel Scroll Speed:\n|cffffffffAdjust how far Sorted should scroll\nper each step of the scroll wheel.\n\n|cffffee00(You can hold ALT at any time to scroll quickly)										
TOOLTIP_CONFIG_SMOOTH_SCROLLING	Smooth Scrolling:\n|cffffffffToggles whether Sorted should smoothly animate\nwhen scrolling. Raise the smoothing strength to\nincrease the duration of the animation.\n\n|cffffee00(Disable to improve performance)	Smooth Scrolling:\n|cffffffffToggles whether Sorted should smoothly animate\nwhen scrolling. Raise the smoothing strength to\nincrease the duration of the animation.\n\n|cffffee00(Disable to improve performance)										
TOOLTIP_CONFIG_RESET_ON_CLOSE	Reset Window on Close:\n|cffffffffLeave unchecked to have Sorted remember\nyour searching, filtering, and sorting options\nafter closing and reopening the window.	Reset Window on Close:\n|cffffffffLeave unchecked to have Sorted remember\nyour searching, filtering, and sorting options\nafter closing and reopening the window.										
TOOLTIP_CONFIG_COMBINE_STACKS	Combine Stacks:\n|cffffffffMerges identical items into one line.\nInteracting with an item will interact with\nthe largest stack of that item in your bags.	Combine Stacks:\n|cffffffffMerges identical items into one line.\nInteracting with an item will interact with\nthe largest stack of that item in your bags.										]]

    for row in string.gmatch(tsv, "[^\r\n]+") do
        local localeID = 0
        local key
        for col in string.gmatch(row, "([^\t]*)\t") do
            if localeID == 0 then
                key = col
            else
                localizations[locales[localeID]][key] = col
            end
            localeID = localeID + 1
        end
    end
end
ParseTSV()

local clientLocale = GetLocale()
function Sorted.Localize(key)
    if localizations[clientLocale][key] and localizations[clientLocale][key] ~= "" then
        return localizations[clientLocale][key]
    elseif localizations["enUS"][key] then
        return localizations["enUS"][key]
    else
        return "["..key.."]"
    end
end

if clientLocale ~= "enUS" and clientLocale ~= "enGB" then
    print("Thank you for using Sorted! Localization for your client's language ("..clientLocale..") is currently incomplete. If you would like to help translate, please go to Sorted's page on CurseForge and scroll to the Languages section.")
end